#[repr(transparent)]pub struct MLCArithmeticOperation(pub i32);MLCTypes only.Expand description
The list of supported arithmetic operations.
See also Apple’s documentation
Tuple Fields
0: i32Implementations
Sourceimpl MLCArithmeticOperation
impl MLCArithmeticOperation
Sourcepub const Subtract: Self
pub const Subtract: Self
An operation that calculates the elementwise difference of its two inputs.
Sourcepub const Multiply: Self
pub const Multiply: Self
An operation that calculates the elementwise product of its two inputs.
Sourcepub const Divide: Self
pub const Divide: Self
An operation that calculates the elementwise division of its two inputs.
Sourcepub const Rsqrt: Self
pub const Rsqrt: Self
An operation that calculates the elementwise reciprocal of the square root of its inputs.
Sourcepub const Acos: Self
pub const Acos: Self
An operation that calculates the elementwise inverse cosine of its inputs.
Sourcepub const Atan: Self
pub const Atan: Self
An operation that calculates the elementwise inverse tangent of its inputs.
Sourcepub const Sinh: Self
pub const Sinh: Self
An operation that calculates the elementwise hyperbolic sine of its inputs.
Sourcepub const Cosh: Self
pub const Cosh: Self
An operation that calculates the elementwise hyperbolic cosine of its inputs.
Sourcepub const Tanh: Self
pub const Tanh: Self
An operation that calculates the elementwise hyperbolic tangent of its inputs.
Sourcepub const Asinh: Self
pub const Asinh: Self
An operation that calculates the elementwise inverse hyperbolic sine of its inputs.
Sourcepub const Acosh: Self
pub const Acosh: Self
An operation that calculates the elementwise inverse hyperbolic cosine of its inputs.
Sourcepub const Atanh: Self
pub const Atanh: Self
An operation that calculates the elementwise inverse hyperbolic tangent of its inputs.
Sourcepub const Pow: Self
pub const Pow: Self
An operation that calculates the elementwise first input raised to the power of its second input.
Sourcepub const Exp: Self
pub const Exp: Self
An operation that calculates the elementwise result of e raised to the power of its input.
Sourcepub const Exp2: Self
pub const Exp2: Self
An operation that calculates the elementwise result of 2 raised to the power of its input.
Sourcepub const Log: Self
pub const Log: Self
An operation that calculates the elementwise natural logarithm of its input.
Sourcepub const Log2: Self
pub const Log2: Self
An operation that calculates the elementwise base 2 logarithm of its input.
Sourcepub const MultiplyNoNaN: Self
pub const MultiplyNoNaN: Self
An operation that calculates the elementwise product of its two inputs. Returns 0 if y in x * y is zero, even if x is NaN or INF
Sourcepub const DivideNoNaN: Self
pub const DivideNoNaN: Self
An operations that calculates the elementwise division of its two inputs. Returns 0 if the denominator is 0.
Sourceimpl MLCArithmeticOperation
impl MLCArithmeticOperation
Sourcepub unsafe fn debug_description(self) -> Retained<NSString>
pub unsafe fn debug_description(self) -> Retained<NSString>
Returns a textual description of the arithmetic operation, suitable for debugging.